# coding: utf-8

# flake8: noqa
"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_detail_body import InsightsApiLegacyInteroperabilityLegacyRemitDetailBody
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_detail_item import InsightsApiLegacyInteroperabilityLegacyRemitDetailItem
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_detail_list import InsightsApiLegacyInteroperabilityLegacyRemitDetailList
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_detail_metadata import InsightsApiLegacyInteroperabilityLegacyRemitDetailMetadata
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_detail_response import InsightsApiLegacyInteroperabilityLegacyRemitDetailResponse
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_list_item import InsightsApiLegacyInteroperabilityLegacyRemitListItem
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_list_metadata import InsightsApiLegacyInteroperabilityLegacyRemitListMetadata
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_list_response import InsightsApiLegacyInteroperabilityLegacyRemitListResponse
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_list_response_body import InsightsApiLegacyInteroperabilityLegacyRemitListResponseBody
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_outage_profile import InsightsApiLegacyInteroperabilityLegacyRemitOutageProfile
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_outage_profile_segment import InsightsApiLegacyInteroperabilityLegacyRemitOutageProfileSegment
from elexonpy.models.insights_api_legacy_interoperability_legacy_remit_response_list import InsightsApiLegacyInteroperabilityLegacyRemitResponseList
from elexonpy.models.insights_api_models_metadata_api_response_source_metadata import InsightsApiModelsMetadataApiResponseSourceMetadata
from elexonpy.models.insights_api_models_responses_balancing_balancing_services_volume import InsightsApiModelsResponsesBalancingBalancingServicesVolume
from elexonpy.models.insights_api_models_responses_balancing_bid_offer_acceptances_response import InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse
from elexonpy.models.insights_api_models_responses_balancing_bid_offer_response import InsightsApiModelsResponsesBalancingBidOfferResponse
from elexonpy.models.insights_api_models_responses_balancing_credit_default_notice_response import InsightsApiModelsResponsesBalancingCreditDefaultNoticeResponse
from elexonpy.models.insights_api_models_responses_balancing_dataset_rows_balancing_services_volume_data import InsightsApiModelsResponsesBalancingDatasetRowsBalancingServicesVolumeData
from elexonpy.models.insights_api_models_responses_balancing_dataset_rows_bid_offer_acceptance_level_dataset_response import InsightsApiModelsResponsesBalancingDatasetRowsBidOfferAcceptanceLevelDatasetResponse
from elexonpy.models.insights_api_models_responses_balancing_dataset_rows_bid_offer_dataset_response import InsightsApiModelsResponsesBalancingDatasetRowsBidOfferDatasetResponse
from elexonpy.models.insights_api_models_responses_balancing_dataset_rows_credit_default_notice_dataset_response import InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse
from elexonpy.models.insights_api_models_responses_balancing_dataset_rows_disaggregated_balancing_services_adjustment_data import InsightsApiModelsResponsesBalancingDatasetRowsDisaggregatedBalancingServicesAdjustmentData
from elexonpy.models.insights_api_models_responses_balancing_dataset_rows_market_index_dataset_response import InsightsApiModelsResponsesBalancingDatasetRowsMarketIndexDatasetResponse
from elexonpy.models.insights_api_models_responses_balancing_dataset_rows_net_balancing_services_adjustment_data import InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData
from elexonpy.models.insights_api_models_responses_balancing_disaggregated_balancing_services_adjustment_details_response import InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentDetailsResponse
from elexonpy.models.insights_api_models_responses_balancing_disaggregated_balancing_services_adjustment_summary_response import InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse
from elexonpy.models.insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_max_data import InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMaxData
from elexonpy.models.insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_min_data import InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData
from elexonpy.models.insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_volume_max_data import InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryVolumeMaxData
from elexonpy.models.insights_api_models_responses_balancing_dynamic_dataset_rows_notice_data import InsightsApiModelsResponsesBalancingDynamicDatasetRowsNoticeData
from elexonpy.models.insights_api_models_responses_balancing_dynamic_dataset_rows_stable_portage_limit_data import InsightsApiModelsResponsesBalancingDynamicDatasetRowsStablePortageLimitData
from elexonpy.models.insights_api_models_responses_balancing_dynamic_dynamic_data import InsightsApiModelsResponsesBalancingDynamicDynamicData
from elexonpy.models.insights_api_models_responses_balancing_dynamic_rate_data import InsightsApiModelsResponsesBalancingDynamicRateData
from elexonpy.models.insights_api_models_responses_balancing_market_index_response import InsightsApiModelsResponsesBalancingMarketIndexResponse
from elexonpy.models.insights_api_models_responses_balancing_net_balancing_services_adjustment_response import InsightsApiModelsResponsesBalancingNetBalancingServicesAdjustmentResponse
from elexonpy.models.insights_api_models_responses_balancing_non_bm_stor_response import InsightsApiModelsResponsesBalancingNonBmStorResponse
from elexonpy.models.insights_api_models_responses_balancing_physical_dataset_rows_delivery_limit_max_data import InsightsApiModelsResponsesBalancingPhysicalDatasetRowsDeliveryLimitMaxData
from elexonpy.models.insights_api_models_responses_balancing_physical_dataset_rows_physical_notification_data import InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData
from elexonpy.models.insights_api_models_responses_balancing_physical_physical_data import InsightsApiModelsResponsesBalancingPhysicalPhysicalData
from elexonpy.models.insights_api_models_responses_balancing_settlement_acceptance_volume_response import InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_derived_data_bid_offer_pairs import InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs
from elexonpy.models.insights_api_models_responses_balancing_settlement_historic_acceptance_response import InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_indicative_cashflow_response import InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_indicative_volume_response import InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_market_depth_response import InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_settlement_message_response import InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_settlement_stack_response import InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_settlement_summary_price import InsightsApiModelsResponsesBalancingSettlementSettlementSummaryPrice
from elexonpy.models.insights_api_models_responses_balancing_settlement_settlement_summary_response import InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse
from elexonpy.models.insights_api_models_responses_balancing_settlement_system_price_response import InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_credit_default_notice_response import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingCreditDefaultNoticeResponse
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dataset_rows_balancing_services_volume_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDatasetRowsBalancingServicesVolumeData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dataset_rows_bid_offer_acceptance_level_dataset_response import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDatasetRowsBidOfferAcceptanceLevelDatasetResponse
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dataset_rows_bid_offer_dataset_response import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDatasetRowsBidOfferDatasetResponse
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dataset_rows_credit_default_notice_dataset_response import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDatasetRowsCreditDefaultNoticeDatasetResponse
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dataset_rows_disaggregated_balancing_services_adjustment_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDatasetRowsDisaggregatedBalancingServicesAdjustmentData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dataset_rows_market_index_dataset_response import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDatasetRowsMarketIndexDatasetResponse
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dataset_rows_net_balancing_services_adjustment_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_max_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMaxData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_min_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_volume_max_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryVolumeMaxData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_notice_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsNoticeData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_stable_portage_limit_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsStablePortageLimitData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_rate_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicRateData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_physical_dataset_rows_delivery_limit_max_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingPhysicalDatasetRowsDeliveryLimitMaxData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_physical_dataset_rows_physical_notification_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_national_daily import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastNationalDaily
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_national_day_ahead import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastNationalDayAhead
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_national_weekly import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastNationalWeekly
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_transmission_daily import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastTransmissionDaily
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_transmission_day_ahead import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastTransmissionDayAhead
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_transmission_weekly import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastTransmissionWeekly
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_outturn_dataset_rows_demand_outturn_national import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandOutturnDatasetRowsDemandOutturnNational
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_outturn_dataset_rows_demand_outturn_transmission import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandOutturnDatasetRowsDemandOutturnTransmission
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_demand_outturn_dataset_rows_indod_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesDemandOutturnDatasetRowsIndodDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_forecast_margin_dataset_rows_forecast_margin_daily import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesForecastMarginDatasetRowsForecastMarginDaily
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_forecast_margin_dataset_rows_forecast_margin_weekly import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesForecastMarginDatasetRowsForecastMarginWeekly
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_forecast_surplus_dataset_rows_forecast_surplus_daily import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_forecast_surplus_dataset_rows_forecast_surplus_weekly import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusWeekly
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_augmented_outturn_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsAugmentedOutturnData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_availability_by_bm_unit_daily import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByBmUnitDaily
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_availability_by_bm_unit_weekly import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByBmUnitWeekly
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_availability_by_fuel_type_daily import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByFuelTypeDaily
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_availability_by_fuel_type_weekly import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByFuelTypeWeekly
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_availability_daily import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityDaily
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_availability_weekly import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityWeekly
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_non_bm_stor_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsNonBmStorData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_generation_dataset_rows_wind_generation_forecast import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesGenerationDatasetRowsWindGenerationForecast
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_indicated_forecast_dataset_rows_indicated_demand import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedDemand
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_indicated_forecast_dataset_rows_indicated_generation import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_indicated_forecast_dataset_rows_indicated_imbalance import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedImbalance
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_indicated_forecast_dataset_rows_indicated_margin import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedMargin
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_demand_control_instruction_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_loss_of_load_probability_derated_margin_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_so_so_prices_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsSoSoPricesDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_system_frequency import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsSystemFrequency
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_system_warnings_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsSystemWarningsData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_temperature_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsTemperatureData
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_tudm_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_reference_dataset_metadata_latest_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesReferenceDatasetMetadataLatestRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_abuc_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsAbucDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_actual_aggregated_generation_per_type_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsActualAggregatedGenerationPerTypeDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_actual_generation_output_per_generation_unit_dataset_response import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsActualGenerationOutputPerGenerationUnitDatasetResponse
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_actual_generation_wind_solar_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsActualGenerationWindSolarDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_actual_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsActualTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_aobe_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsAobeDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_beb_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsBebDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_cbs_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsCbsDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_costs_of_congestion_management_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsCostsOfCongestionManagementDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_day_ahead_aggregated_generation_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadAggregatedGenerationDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_day_ahead_generation_for_wind_and_solar_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_day_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_feib_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsFeibDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_igca_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsIgcaDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_igcpu_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_month_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsMonthAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_pbc_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsPbcDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_ppbr_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsPpbrDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_week_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsWeekAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_year_ahead_forecast_margin_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadForecastMarginDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_dataset_rows_year_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_transparency_remit_dataset_rows_remit_message import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesTransparencyRemitDatasetRowsRemitMessage
from elexonpy.models.insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_national_daily import InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastNationalDaily
from elexonpy.models.insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_national_day_ahead import InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastNationalDayAhead
from elexonpy.models.insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_national_weekly import InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastNationalWeekly
from elexonpy.models.insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_transmission_daily import InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastTransmissionDaily
from elexonpy.models.insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_transmission_day_ahead import InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastTransmissionDayAhead
from elexonpy.models.insights_api_models_responses_demand_forecast_dataset_rows_demand_forecast_transmission_weekly import InsightsApiModelsResponsesDemandForecastDatasetRowsDemandForecastTransmissionWeekly
from elexonpy.models.insights_api_models_responses_demand_forecast_demand_forecast_daily import InsightsApiModelsResponsesDemandForecastDemandForecastDaily
from elexonpy.models.insights_api_models_responses_demand_forecast_demand_forecast_day_ahead import InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
from elexonpy.models.insights_api_models_responses_demand_forecast_demand_forecast_peak import InsightsApiModelsResponsesDemandForecastDemandForecastPeak
from elexonpy.models.insights_api_models_responses_demand_forecast_demand_forecast_weekly import InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
from elexonpy.models.insights_api_models_responses_demand_outturn_dataset_rows_demand_outturn_national import InsightsApiModelsResponsesDemandOutturnDatasetRowsDemandOutturnNational
from elexonpy.models.insights_api_models_responses_demand_outturn_dataset_rows_demand_outturn_transmission import InsightsApiModelsResponsesDemandOutturnDatasetRowsDemandOutturnTransmission
from elexonpy.models.insights_api_models_responses_demand_outturn_dataset_rows_indod_dataset_row import InsightsApiModelsResponsesDemandOutturnDatasetRowsIndodDatasetRow
from elexonpy.models.insights_api_models_responses_demand_outturn_demand_outturn import InsightsApiModelsResponsesDemandOutturnDemandOutturn
from elexonpy.models.insights_api_models_responses_demand_outturn_demand_outturn_peak import InsightsApiModelsResponsesDemandOutturnDemandOutturnPeak
from elexonpy.models.insights_api_models_responses_demand_outturn_indicative_demand_peak import InsightsApiModelsResponsesDemandOutturnIndicativeDemandPeak
from elexonpy.models.insights_api_models_responses_demand_outturn_indod_row import InsightsApiModelsResponsesDemandOutturnIndodRow
from elexonpy.models.insights_api_models_responses_demand_outturn_rolling_system_demand import InsightsApiModelsResponsesDemandOutturnRollingSystemDemand
from elexonpy.models.insights_api_models_responses_forecast_margin_dataset_rows_forecast_margin_daily import InsightsApiModelsResponsesForecastMarginDatasetRowsForecastMarginDaily
from elexonpy.models.insights_api_models_responses_forecast_margin_dataset_rows_forecast_margin_weekly import InsightsApiModelsResponsesForecastMarginDatasetRowsForecastMarginWeekly
from elexonpy.models.insights_api_models_responses_forecast_margin_forecast_margin_daily import InsightsApiModelsResponsesForecastMarginForecastMarginDaily
from elexonpy.models.insights_api_models_responses_forecast_margin_forecast_margin_weekly import InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
from elexonpy.models.insights_api_models_responses_forecast_surplus_dataset_rows_forecast_surplus_daily import InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusDaily
from elexonpy.models.insights_api_models_responses_forecast_surplus_dataset_rows_forecast_surplus_weekly import InsightsApiModelsResponsesForecastSurplusDatasetRowsForecastSurplusWeekly
from elexonpy.models.insights_api_models_responses_forecast_surplus_forecast_surplus_daily import InsightsApiModelsResponsesForecastSurplusForecastSurplusDaily
from elexonpy.models.insights_api_models_responses_forecast_surplus_forecast_surplus_weekly import InsightsApiModelsResponsesForecastSurplusForecastSurplusWeekly
from elexonpy.models.insights_api_models_responses_generation_aggregated_forecast import InsightsApiModelsResponsesGenerationAggregatedForecast
from elexonpy.models.insights_api_models_responses_generation_availability_daily import InsightsApiModelsResponsesGenerationAvailabilityDaily
from elexonpy.models.insights_api_models_responses_generation_availability_weekly import InsightsApiModelsResponsesGenerationAvailabilityWeekly
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_augmented_outturn_data import InsightsApiModelsResponsesGenerationDatasetRowsAugmentedOutturnData
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_availability_by_bm_unit_daily import InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByBmUnitDaily
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_availability_by_bm_unit_weekly import InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByBmUnitWeekly
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_availability_by_fuel_type_daily import InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByFuelTypeDaily
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_availability_by_fuel_type_weekly import InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityByFuelTypeWeekly
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_availability_daily import InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityDaily
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_availability_weekly import InsightsApiModelsResponsesGenerationDatasetRowsAvailabilityWeekly
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_non_bm_stor_data import InsightsApiModelsResponsesGenerationDatasetRowsNonBmStorData
from elexonpy.models.insights_api_models_responses_generation_dataset_rows_wind_generation_forecast import InsightsApiModelsResponsesGenerationDatasetRowsWindGenerationForecast
from elexonpy.models.insights_api_models_responses_generation_forecast_fuel_data import InsightsApiModelsResponsesGenerationForecastFuelData
from elexonpy.models.insights_api_models_responses_generation_generation_by_fuel_type import InsightsApiModelsResponsesGenerationGenerationByFuelType
from elexonpy.models.insights_api_models_responses_generation_half_hourly_interconnector_outturn import InsightsApiModelsResponsesGenerationHalfHourlyInterconnectorOutturn
from elexonpy.models.insights_api_models_responses_generation_outturn_generation_by_settlement_period import InsightsApiModelsResponsesGenerationOutturnGenerationBySettlementPeriod
from elexonpy.models.insights_api_models_responses_generation_outturn_generation_value import InsightsApiModelsResponsesGenerationOutturnGenerationValue
from elexonpy.models.insights_api_models_responses_generation_wind_generation_forecast import InsightsApiModelsResponsesGenerationWindGenerationForecast
from elexonpy.models.insights_api_models_responses_indicated_forecast_dataset_rows_indicated_demand import InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedDemand
from elexonpy.models.insights_api_models_responses_indicated_forecast_dataset_rows_indicated_generation import InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration
from elexonpy.models.insights_api_models_responses_indicated_forecast_dataset_rows_indicated_imbalance import InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedImbalance
from elexonpy.models.insights_api_models_responses_indicated_forecast_dataset_rows_indicated_margin import InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedMargin
from elexonpy.models.insights_api_models_responses_indicated_forecast_indicated_forecast import InsightsApiModelsResponsesIndicatedForecastIndicatedForecast
from elexonpy.models.insights_api_models_responses_misc_dataset_rows_demand_control_instruction_dataset_row import InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow
from elexonpy.models.insights_api_models_responses_misc_dataset_rows_loss_of_load_probability_derated_margin_data import InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData
from elexonpy.models.insights_api_models_responses_misc_dataset_rows_so_so_prices_dataset_row import InsightsApiModelsResponsesMiscDatasetRowsSoSoPricesDatasetRow
from elexonpy.models.insights_api_models_responses_misc_dataset_rows_system_frequency import InsightsApiModelsResponsesMiscDatasetRowsSystemFrequency
from elexonpy.models.insights_api_models_responses_misc_dataset_rows_system_warnings_data import InsightsApiModelsResponsesMiscDatasetRowsSystemWarningsData
from elexonpy.models.insights_api_models_responses_misc_dataset_rows_temperature_data import InsightsApiModelsResponsesMiscDatasetRowsTemperatureData
from elexonpy.models.insights_api_models_responses_misc_dataset_rows_tudm_dataset_row import InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow
from elexonpy.models.insights_api_models_responses_misc_demand_control_instruction_data import InsightsApiModelsResponsesMiscDemandControlInstructionData
from elexonpy.models.insights_api_models_responses_misc_loss_of_load_probability_derated_margin_response import InsightsApiModelsResponsesMiscLossOfLoadProbabilityDeratedMarginResponse
from elexonpy.models.insights_api_models_responses_misc_so_so_prices import InsightsApiModelsResponsesMiscSoSoPrices
from elexonpy.models.insights_api_models_responses_misc_system_frequency import InsightsApiModelsResponsesMiscSystemFrequency
from elexonpy.models.insights_api_models_responses_misc_system_warnings_data import InsightsApiModelsResponsesMiscSystemWarningsData
from elexonpy.models.insights_api_models_responses_misc_temperature_data import InsightsApiModelsResponsesMiscTemperatureData
from elexonpy.models.insights_api_models_responses_reference_bm_unit_data import InsightsApiModelsResponsesReferenceBmUnitData
from elexonpy.models.insights_api_models_responses_reference_dataset_metadata_latest_row import InsightsApiModelsResponsesReferenceDatasetMetadataLatestRow
from elexonpy.models.insights_api_models_responses_reference_interconnector_data import InsightsApiModelsResponsesReferenceInterconnectorData
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_balancing_services_volume import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBalancingServicesVolume
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_bid_offer_acceptances_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_bid_offer_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_disaggregated_balancing_services_adjustment_details_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentDetailsResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_disaggregated_balancing_services_adjustment_summary_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_dynamic_dynamic_data import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicDynamicData
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_dynamic_rate_data import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingDynamicRateData
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_market_index_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingMarketIndexResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_net_balancing_services_adjustment_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNetBalancingServicesAdjustmentResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_non_bm_stor_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNonBmStorResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_physical_physical_data import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingPhysicalPhysicalData
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_acceptance_volume_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementAcceptanceVolumeResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_historic_acceptance_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_indicative_cashflow_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_indicative_volume_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementIndicativeVolumeResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_market_depth_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_settlement_message_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementMessageResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_settlement_stack_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_balancing_settlement_system_price_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_forecast_demand_forecast_daily import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_forecast_demand_forecast_day_ahead import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_forecast_demand_forecast_peak import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastPeak
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_forecast_demand_forecast_weekly import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_outturn_demand_outturn import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnDemandOutturn
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_outturn_demand_outturn_peak import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnDemandOutturnPeak
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_outturn_indicative_demand_peak import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnIndicativeDemandPeak
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_outturn_indod_row import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnIndodRow
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_demand_outturn_rolling_system_demand import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnRollingSystemDemand
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_forecast_margin_forecast_margin_daily import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_forecast_margin_forecast_margin_weekly import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_forecast_surplus_forecast_surplus_daily import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastSurplusForecastSurplusDaily
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_forecast_surplus_forecast_surplus_weekly import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastSurplusForecastSurplusWeekly
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_generation_availability_daily import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_generation_availability_weekly import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_generation_half_hourly_interconnector_outturn import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationHalfHourlyInterconnectorOutturn
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_generation_wind_generation_forecast import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_indicated_forecast_indicated_forecast import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesIndicatedForecastIndicatedForecast
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_misc_demand_control_instruction_data import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscDemandControlInstructionData
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_misc_loss_of_load_probability_derated_margin_response import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscLossOfLoadProbabilityDeratedMarginResponse
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_misc_so_so_prices import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSoSoPrices
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_misc_system_frequency import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemFrequency
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_misc_system_warnings_data import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemWarningsData
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_misc_temperature_data import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscTemperatureData
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_actual_generation_by_settlement_period import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyActualGenerationBySettlementPeriod
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_actual_generation_wind_solar import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyActualGenerationWindSolar
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_actual_total_load_per_bidding_zone import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyActualTotalLoadPerBiddingZone
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_day_ahead_aggregated_generation import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadAggregatedGeneration
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_day_ahead_generation_for_wind_and_solar import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadGenerationForWindAndSolar
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_day_ahead_total_load_per_bidding_zone import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadTotalLoadPerBiddingZone
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_remit_remit_message_identifier_with_url import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_remit_remit_message_with_id import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_week_ahead_total_load_per_bidding_zone import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone
from elexonpy.models.insights_api_models_responses_transparency_actual_generation_by_settlement_period import InsightsApiModelsResponsesTransparencyActualGenerationBySettlementPeriod
from elexonpy.models.insights_api_models_responses_transparency_actual_generation_value import InsightsApiModelsResponsesTransparencyActualGenerationValue
from elexonpy.models.insights_api_models_responses_transparency_actual_generation_wind_solar import InsightsApiModelsResponsesTransparencyActualGenerationWindSolar
from elexonpy.models.insights_api_models_responses_transparency_actual_total_load_per_bidding_zone import InsightsApiModelsResponsesTransparencyActualTotalLoadPerBiddingZone
from elexonpy.models.insights_api_models_responses_transparency_agpt_summary_data import InsightsApiModelsResponsesTransparencyAgptSummaryData
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_abuc_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsAbucDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_actual_aggregated_generation_per_type_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsActualAggregatedGenerationPerTypeDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_actual_generation_output_per_generation_unit_dataset_response import InsightsApiModelsResponsesTransparencyDatasetRowsActualGenerationOutputPerGenerationUnitDatasetResponse
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_actual_generation_wind_solar_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsActualGenerationWindSolarDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_actual_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsActualTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_aobe_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsAobeDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_beb_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsBebDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_cbs_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsCbsDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_costs_of_congestion_management_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsCostsOfCongestionManagementDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_day_ahead_aggregated_generation_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadAggregatedGenerationDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_day_ahead_generation_for_wind_and_solar_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_day_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_feib_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsFeibDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_igca_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsIgcaDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_igcpu_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_month_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsMonthAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_pbc_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsPbcDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_ppbr_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsPpbrDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_week_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsWeekAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_year_ahead_forecast_margin_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadForecastMarginDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_dataset_rows_year_ahead_total_load_per_bidding_zone_dataset_row import InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow
from elexonpy.models.insights_api_models_responses_transparency_day_ahead_aggregated_generation import InsightsApiModelsResponsesTransparencyDayAheadAggregatedGeneration
from elexonpy.models.insights_api_models_responses_transparency_day_ahead_generation_for_wind_and_solar import InsightsApiModelsResponsesTransparencyDayAheadGenerationForWindAndSolar
from elexonpy.models.insights_api_models_responses_transparency_day_ahead_total_load_per_bidding_zone import InsightsApiModelsResponsesTransparencyDayAheadTotalLoadPerBiddingZone
from elexonpy.models.insights_api_models_responses_transparency_remit_dataset_rows_outage_profile_data import InsightsApiModelsResponsesTransparencyRemitDatasetRowsOutageProfileData
from elexonpy.models.insights_api_models_responses_transparency_remit_dataset_rows_remit_message import InsightsApiModelsResponsesTransparencyRemitDatasetRowsRemitMessage
from elexonpy.models.insights_api_models_responses_transparency_remit_remit_message_identifier_with_url import InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
from elexonpy.models.insights_api_models_responses_transparency_remit_remit_message_with_id import InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
from elexonpy.models.insights_api_models_responses_transparency_week_ahead_total_load_per_bidding_zone import InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone
from elexonpy.models.insights_api_models_service_day_ahead_demand_forecast_row import InsightsApiModelsServiceDayAheadDemandForecastRow
from elexonpy.models.insights_api_models_service_wind_generation_forecast_row import InsightsApiModelsServiceWindGenerationForecastRow



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_remit_remit_message_identifier_with_url import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl  # noqa: E501
from elexonpy.rest import ApiException


class TestInsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl(unittest.TestCase):
    """InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl(self):
        """Test InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl"""
        # FIXME: construct object with mandatory attributes with example values
        # model = elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_remit_remit_message_identifier_with_url.InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.indicated_forecast_api import IndicatedForecastApi  # noqa: E501
from elexonpy.rest import ApiException


class TestIndicatedForecastApi(unittest.TestCase):
    """IndicatedForecastApi unit test stubs"""

    def setUp(self):
        self.api = IndicatedForecastApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_forecast_indicated_day_ahead_evolution_get(self):
        """Test case for forecast_indicated_day_ahead_evolution_get

        Evolution indicated day-ahead forecast (INDDEM, INDGEN, IMBALNGC, MELNGC)  # noqa: E501
        """
        pass

    def test_forecast_indicated_day_ahead_get(self):
        """Test case for forecast_indicated_day_ahead_get

        Latest indicated day-ahead forecast (INDDEM, INDGEN, IMBALNGC, MELNGC)  # noqa: E501
        """
        pass

    def test_forecast_indicated_day_ahead_history_get(self):
        """Test case for forecast_indicated_day_ahead_history_get

        Historical indicated day-ahead forecast (INDDEM, INDGEN, IMBALNGC, MELNGC)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_date': 'date',
        'settlement_period': 'int',
        'bm_unit': 'str',
        'national_grid_bm_unit': 'str',
        'acceptance_number': 'int',
        'acceptance_time': 'datetime',
        'bid_price': 'float',
        'offer_price': 'float',
        'bid_offer_pair_id': 'int'
    }

    attribute_map = {
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'bm_unit': 'bmUnit',
        'national_grid_bm_unit': 'nationalGridBmUnit',
        'acceptance_number': 'acceptanceNumber',
        'acceptance_time': 'acceptanceTime',
        'bid_price': 'bidPrice',
        'offer_price': 'offerPrice',
        'bid_offer_pair_id': 'bidOfferPairId'
    }

    def __init__(self, settlement_date=None, settlement_period=None, bm_unit=None, national_grid_bm_unit=None, acceptance_number=None, acceptance_time=None, bid_price=None, offer_price=None, bid_offer_pair_id=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse - a model defined in Swagger"""  # noqa: E501
        self._settlement_date = None
        self._settlement_period = None
        self._bm_unit = None
        self._national_grid_bm_unit = None
        self._acceptance_number = None
        self._acceptance_time = None
        self._bid_price = None
        self._offer_price = None
        self._bid_offer_pair_id = None
        self.discriminator = None
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if bm_unit is not None:
            self.bm_unit = bm_unit
        if national_grid_bm_unit is not None:
            self.national_grid_bm_unit = national_grid_bm_unit
        if acceptance_number is not None:
            self.acceptance_number = acceptance_number
        if acceptance_time is not None:
            self.acceptance_time = acceptance_time
        if bid_price is not None:
            self.bid_price = bid_price
        if offer_price is not None:
            self.offer_price = offer_price
        if bid_offer_pair_id is not None:
            self.bid_offer_pair_id = bid_offer_pair_id

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def bm_unit(self):
        """Gets the bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit

    @bm_unit.setter
    def bm_unit(self, bm_unit):
        """Sets the bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param bm_unit: The bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: str
        """

        self._bm_unit = bm_unit

    @property
    def national_grid_bm_unit(self):
        """Gets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._national_grid_bm_unit

    @national_grid_bm_unit.setter
    def national_grid_bm_unit(self, national_grid_bm_unit):
        """Sets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param national_grid_bm_unit: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: str
        """

        self._national_grid_bm_unit = national_grid_bm_unit

    @property
    def acceptance_number(self):
        """Gets the acceptance_number of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The acceptance_number of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: int
        """
        return self._acceptance_number

    @acceptance_number.setter
    def acceptance_number(self, acceptance_number):
        """Sets the acceptance_number of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param acceptance_number: The acceptance_number of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: int
        """

        self._acceptance_number = acceptance_number

    @property
    def acceptance_time(self):
        """Gets the acceptance_time of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The acceptance_time of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._acceptance_time

    @acceptance_time.setter
    def acceptance_time(self, acceptance_time):
        """Sets the acceptance_time of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param acceptance_time: The acceptance_time of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: datetime
        """

        self._acceptance_time = acceptance_time

    @property
    def bid_price(self):
        """Gets the bid_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The bid_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: float
        """
        return self._bid_price

    @bid_price.setter
    def bid_price(self, bid_price):
        """Sets the bid_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param bid_price: The bid_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: float
        """

        self._bid_price = bid_price

    @property
    def offer_price(self):
        """Gets the offer_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The offer_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: float
        """
        return self._offer_price

    @offer_price.setter
    def offer_price(self, offer_price):
        """Sets the offer_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param offer_price: The offer_price of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: float
        """

        self._offer_price = offer_price

    @property
    def bid_offer_pair_id(self):
        """Gets the bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501


        :return: The bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :rtype: int
        """
        return self._bid_offer_pair_id

    @bid_offer_pair_id.setter
    def bid_offer_pair_id(self, bid_offer_pair_id):
        """Sets the bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.


        :param bid_offer_pair_id: The bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse.  # noqa: E501
        :type: int
        """

        self._bid_offer_pair_id = bid_offer_pair_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingSettlementHistoricAcceptanceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'document_id': 'str',
        'document_revision_number': 'int',
        'publish_time': 'datetime',
        'forecast_year': 'int',
        'forecast_week': 'int',
        'minimum_possible': 'float',
        'maximum_available': 'float'
    }

    attribute_map = {
        'dataset': 'dataset',
        'document_id': 'documentId',
        'document_revision_number': 'documentRevisionNumber',
        'publish_time': 'publishTime',
        'forecast_year': 'forecastYear',
        'forecast_week': 'forecastWeek',
        'minimum_possible': 'minimumPossible',
        'maximum_available': 'maximumAvailable'
    }

    def __init__(self, dataset=None, document_id=None, document_revision_number=None, publish_time=None, forecast_year=None, forecast_week=None, minimum_possible=None, maximum_available=None):  # noqa: E501
        """InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._document_id = None
        self._document_revision_number = None
        self._publish_time = None
        self._forecast_year = None
        self._forecast_week = None
        self._minimum_possible = None
        self._maximum_available = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if document_id is not None:
            self.document_id = document_id
        if document_revision_number is not None:
            self.document_revision_number = document_revision_number
        if publish_time is not None:
            self.publish_time = publish_time
        if forecast_year is not None:
            self.forecast_year = forecast_year
        if forecast_week is not None:
            self.forecast_week = forecast_week
        if minimum_possible is not None:
            self.minimum_possible = minimum_possible
        if maximum_available is not None:
            self.maximum_available = maximum_available

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param dataset: The dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def document_id(self):
        """Gets the document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param document_id: The document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def document_revision_number(self):
        """Gets the document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._document_revision_number

    @document_revision_number.setter
    def document_revision_number(self, document_revision_number):
        """Sets the document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param document_revision_number: The document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: int
        """

        self._document_revision_number = document_revision_number

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def forecast_year(self):
        """Gets the forecast_year of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The forecast_year of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._forecast_year

    @forecast_year.setter
    def forecast_year(self, forecast_year):
        """Sets the forecast_year of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param forecast_year: The forecast_year of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: int
        """

        self._forecast_year = forecast_year

    @property
    def forecast_week(self):
        """Gets the forecast_week of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The forecast_week of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._forecast_week

    @forecast_week.setter
    def forecast_week(self, forecast_week):
        """Sets the forecast_week of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param forecast_week: The forecast_week of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: int
        """

        self._forecast_week = forecast_week

    @property
    def minimum_possible(self):
        """Gets the minimum_possible of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The minimum_possible of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._minimum_possible

    @minimum_possible.setter
    def minimum_possible(self, minimum_possible):
        """Sets the minimum_possible of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param minimum_possible: The minimum_possible of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: float
        """

        self._minimum_possible = minimum_possible

    @property
    def maximum_available(self):
        """Gets the maximum_available of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501


        :return: The maximum_available of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._maximum_available

    @maximum_available.setter
    def maximum_available(self, maximum_available):
        """Sets the maximum_available of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.


        :param maximum_available: The maximum_available of this InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow.  # noqa: E501
        :type: float
        """

        self._maximum_available = maximum_available

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesTransparencyDatasetRowsYearAheadTotalLoadPerBiddingZoneDatasetRow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.remit_api import REMITApi  # noqa: E501
from elexonpy.rest import ApiException


class TestREMITApi(unittest.TestCase):
    """REMITApi unit test stubs"""

    def setUp(self):
        self.api = REMITApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_remit_get(self):
        """Test case for remit_get

        Bulk fetch message details by IDs  # noqa: E501
        """
        pass

    def test_remit_list_by_event_get(self):
        """Test case for remit_list_by_event_get

        List messages by event time  # noqa: E501
        """
        pass

    def test_remit_list_by_event_stream_get(self):
        """Test case for remit_list_by_event_stream_get

        List messages by event time (stream)  # noqa: E501
        """
        pass

    def test_remit_list_by_publish_get(self):
        """Test case for remit_list_by_publish_get

        List messages by publish time  # noqa: E501
        """
        pass

    def test_remit_list_by_publish_stream_get(self):
        """Test case for remit_list_by_publish_stream_get

        List messages by publish time (stream)  # noqa: E501
        """
        pass

    def test_remit_message_id_get(self):
        """Test case for remit_message_id_get

        Fetch message details by ID  # noqa: E501
        """
        pass

    def test_remit_revisions_get(self):
        """Test case for remit_revisions_get

        List all message revisions  # noqa: E501
        """
        pass

    def test_remit_search_get(self):
        """Test case for remit_search_get

        Fetch message details by mRID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from elexonpy.api.availability_api import AvailabilityApi
from elexonpy.api.balancing_mechanism_dynamic_api import BalancingMechanismDynamicApi
from elexonpy.api.balancing_mechanism_physical_api import BalancingMechanismPhysicalApi
from elexonpy.api.balancing_services_adjustment___disaggregated_api import BalancingServicesAdjustmentDisaggregatedApi
from elexonpy.api.balancing_services_adjustment___net_api import BalancingServicesAdjustmentNetApi
from elexonpy.api.bid_offer_api import BidOfferApi
from elexonpy.api.bid_offer_acceptances_api import BidOfferAcceptancesApi
from elexonpy.api.credit_default_notice_api import CreditDefaultNoticeApi
from elexonpy.api.datasets_api import DatasetsApi
from elexonpy.api.demand_api import DemandApi
from elexonpy.api.demand_forecast_api import DemandForecastApi
from elexonpy.api.generation_api import GenerationApi
from elexonpy.api.generation_forecast_api import GenerationForecastApi
from elexonpy.api.health_check_api import HealthCheckApi
from elexonpy.api.indicated_forecast_api import IndicatedForecastApi
from elexonpy.api.indicative_imbalance_settlement_api import IndicativeImbalanceSettlementApi
from elexonpy.api.legacy_api import LegacyApi
from elexonpy.api.loss_of_load_probability_and_de_rated_margin_api import LossOfLoadProbabilityAndDeRatedMarginApi
from elexonpy.api.margin_forecast_api import MarginForecastApi
from elexonpy.api.market_index_api import MarketIndexApi
from elexonpy.api.non_bm_stor_api import NonBMSTORApi
from elexonpy.api.non_bm_volumes_api import NonBMVolumesApi
from elexonpy.api.remit_api import REMITApi
from elexonpy.api.reference_api import ReferenceApi
from elexonpy.api.rolling_system_demand_api import RollingSystemDemandApi
from elexonpy.api.so_so_prices_api import SOSOPricesApi
from elexonpy.api.surplus_forecast_api import SurplusForecastApi
from elexonpy.api.system_api import SystemApi
from elexonpy.api.system_forecast_api import SystemForecastApi
from elexonpy.api.temperature_api import TemperatureApi



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.system_api import SystemApi  # noqa: E501
from elexonpy.rest import ApiException


class TestSystemApi(unittest.TestCase):
    """SystemApi unit test stubs"""

    def setUp(self):
        self.api = SystemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_system_demand_control_instructions_get(self):
        """Test case for system_demand_control_instructions_get

        Demand control instructions (DCI)  # noqa: E501
        """
        pass

    def test_system_frequency_get(self):
        """Test case for system_frequency_get

        System frequency (FREQ)  # noqa: E501
        """
        pass

    def test_system_frequency_stream_get(self):
        """Test case for system_frequency_stream_get

        System frequency (FREQ) stream  # noqa: E501
        """
        pass

    def test_system_warnings_get(self):
        """Test case for system_warnings_get

        System warnings (SYSWARN)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
